typedef unsigned char cfg_u8;
typedef union {
    struct {
        cfg_u8 offset;
        cfg_u8 value;
    };
    struct {
        cfg_u8 command;
        cfg_u8 param;
    };
} cfg_reg;

#define CFG_META_SWITCH (255)
#define CFG_META_DELAY  (254)
#define CFG_META_BURST  (253)

/* Example C code */
/*
    // Externally implemented function that can write n-bytes to the device
    extern int i2c_write(unsigned char *data, int n);
    // Externally implemented function that delays execution by n milliseconds
    extern int delay(int n);
    // Example implementation.  Call like:
    //     transmit_registers(registers, sizeof(registers)/sizeof(registers[0]));
    void transmit_registers(cfg_reg *r, int n)
    {
        int i = 0;
        while (i < n) {
            switch (r[i].command) {
            case CFG_META_SWITCH:
                // Used in legacy applications.  Ignored here.
                break;
            case CFG_META_DELAY:
                delay(r[i].param);
                break;
            case CFG_META_BURST:
                i2c_write((unsigned char *)&r[i+1], r[i].param);
                i += (r[i].param + 1)/2;
                break;
            default:
                i2c_write((unsigned char *)&r[i], 2);
                break;
            }
            i++;
        }
    }
 */

cfg_reg registers[] = {
    { 0x00, 0xA4 },
    { 0x01, 0x04 },
    { 0x02, 0x00 },
    { 0x03, 0xA0 },
    { 0x04, 0x53 },
    { 0x05, 0xE0 },
    { 0x06, 0xE0 },
    { 0x07, 0xE0 },
    { 0x08, 0xE0 },
    { 0x09, 0xE0 },
    { 0x0A, 0xE0 },
    { 0x0B, 0xE0 },
    { 0x0C, 0xE0 },
    { 0x0D, 0x00 },
    { 0x0E, 0x55 },
    { 0x0F, 0x00 },
    { 0x10, 0x0A },
    { 0x11, 0x91 },
    { 0x12, 0xC0 },
    { 0x13, 0x80 },
    { 0x14, 0x44 },
    { 0x15, 0x02 },
    { 0x16, 0x77 },
    { 0x17, 0x77 },
    { 0x18, 0x77 },
    { 0x19, 0x77 },
    { 0x1A, 0x55 },
    { 0x1B, 0x80 },
    { 0x1C, 0x00 },
    { 0x1D, 0xC0 },
    { 0x1E, 0x40 },
    { 0x1F, 0xA0 },
    { 0x20, 0x20 },
    { 0x21, 0xE0 },
    { 0x22, 0x60 },
    { 0x23, 0x00 },
    { 0x24, 0x0F },
    { 0x25, 0x80 },
    { 0x26, 0xFF },
    { 0x27, 0x00 },
    { 0x28, 0x10 },
    { 0x29, 0x55 },
    { 0x2A, 0x55 },
    { 0x2B, 0x55 },
    { 0x2C, 0x55 },
    { 0x2D, 0x00 },
    { 0x2E, 0x00 },
    { 0x2F, 0x00 },
    { 0x30, 0x01 },
    { 0x31, 0x23 },
    { 0x32, 0x45 },
    { 0x33, 0x67 },
    { 0x34, 0x01 },
    { 0x35, 0x23 },
    { 0x36, 0x45 },
    { 0x37, 0x67 },
    { 0x38, 0x80 },
    { 0x39, 0x00 },
    { 0x3A, 0xC0 },
    { 0x3B, 0x40 },
    { 0x3C, 0xA0 },
    { 0x3D, 0x20 },
    { 0x3E, 0xE0 },
    { 0x3F, 0x60 },
    { CFG_META_BURST, 0x05 },
        { 0x40, 0x00 },
        { 0x00, 0xFF },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x41, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x88, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x42, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x43, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x44, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x45, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x46, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x47, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x21 },
        { 0x48, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x49, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x4A, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x4B, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x4C, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x4D, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x4E, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x4F, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x50, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x51, 0x00 },
        { 0x7F, 0xDD },
        { 0xD7, 0x0F },
        { 0x00, 0x44 },
        { 0x53, 0x00 },
        { 0x7F, 0xDD },
        { 0xD7, 0x00 },
        { 0xFF, 0xBB },
        { 0x89, 0x0F },
        { 0x80, 0x44 },
        { 0x2F, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x52, 0x00 },
        { 0x00, 0x00 },
        { 0x81, 0x00 },
        { 0x00, 0x01 },
        { 0x02, 0x00 },
        { 0x00, 0x00 },
        { 0x81, 0x00 },
        { 0xFF, 0x48 },
        { 0x7B, 0x0F },
        { 0x80, 0xB5 },
        { 0x81, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x53, 0x00 },
        { 0x80, 0x24 },
        { 0x5F, 0x0F },
        { 0x00, 0x21 },
        { 0xD0, 0x00 },
        { 0x7F, 0xB9 },
        { 0xFD, 0x00 },
        { 0xFF, 0xDE },
        { 0x30, 0x0F },
        { 0x80, 0x21 },
        { 0xA4, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x54, 0x00 },
        { 0x80, 0x16 },
        { 0x15, 0x0F },
        { 0x00, 0x6B },
        { 0x69, 0x00 },
        { 0x7F, 0x7E },
        { 0xDC, 0x00 },
        { 0xFF, 0x94 },
        { 0x97, 0x0F },
        { 0x80, 0x6B },
        { 0x0F, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x55, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x56, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x57, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x58, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x59, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x5A, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x5B, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x5C, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x5D, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x5E, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x5F, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x60, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x61, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x62, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x63, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x64, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x65, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x66, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x67, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x68, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x69, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x6A, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x6B, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x6C, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x6D, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x6E, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x6F, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x70, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x71, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x72, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x73, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x74, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x75, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x76, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x77, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x78, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x79, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x7A, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x7B, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x7C, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x7D, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x7E, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x7F, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x80, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x81, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x82, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x83, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x84, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x85, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x86, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x87, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x88, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x89, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x8A, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x8B, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x8C, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x8D, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x8E, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x8F, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x90, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x91, 0x0F },
        { 0xC0, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x92, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x93, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x94, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0x95, 0x00 },
        { 0xFE, 0x50 },
        { 0x45, 0x0F },
        { 0x81, 0xAA },
        { 0x27, 0x00 },
        { 0x00, 0xD5 },
        { 0x13, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x0F },
        { 0xFF, 0x2A },
        { 0xED, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x96, 0x00 },
        { 0x00, 0x00 },
        { 0x02, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0x97, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x98, 0x00 },
        { 0x00, 0x44 },
        { 0x32, 0x00 },
        { 0x7F, 0xBB },
        { 0xCE, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x99, 0x0B },
        { 0x20, 0xE2 },
        { 0xB0, 0x02 },
        { 0xD2, 0xD9 },
        { 0xFF, 0x00 },
    { CFG_META_BURST, 0x0D },
        { 0x9A, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x0F },
        { 0x80, 0xA3 },
        { 0xD7, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x9B, 0x02 },
        { 0x00, 0x00 },
        { 0x00, 0x02 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x11 },
        { 0x9C, 0x00 },
        { 0x00, 0x44 },
        { 0x32, 0x00 },
        { 0x7F, 0xBB },
        { 0xCE, 0x00 },
        { 0x00, 0xAA },
        { 0x39, 0x00 },
        { 0x7F, 0x55 },
        { 0xC7, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x9D, 0x00 },
        { 0x00, 0x44 },
        { 0x32, 0x00 },
        { 0x7F, 0xBB },
        { 0xCE, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0x9E, 0x0B },
        { 0x20, 0xE2 },
        { 0xB0, 0x06 },
        { 0xF9, 0xDE },
        { 0x57, 0x00 },
    { CFG_META_BURST, 0x0D },
        { 0x9F, 0x00 },
        { 0x40, 0x00 },
        { 0x00, 0x0F },
        { 0xC0, 0x00 },
        { 0x00, 0x0F },
        { 0x90, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA0, 0xFF },
        { 0x82, 0x30 },
        { 0x98, 0x01 },
        { 0x95, 0xB2 },
        { 0xC4, 0x00 },
    { CFG_META_BURST, 0x11 },
        { 0xA1, 0x00 },
        { 0x00, 0x44 },
        { 0x32, 0x00 },
        { 0x7F, 0xBB },
        { 0xCE, 0x00 },
        { 0x00, 0xAA },
        { 0x39, 0x00 },
        { 0x7F, 0x55 },
        { 0xC7, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA2, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA3, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA4, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA5, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA6, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA7, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA8, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xA9, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xAA, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xAB, 0x10 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xAC, 0x20 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xAD, 0x30 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xAE, 0x40 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x09 },
        { 0xAF, 0x50 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x0D },
        { 0xB0, 0x60 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x0D },
        { 0xB1, 0x70 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x11 },
        { 0xB2, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB3, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB4, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB5, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB6, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB7, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB8, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xB9, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xBA, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xBB, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xBC, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xBD, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xBE, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xBF, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC0, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC1, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC2, 0x00 },
        { 0x00, 0x00 },
        { 0x80, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC3, 0x11 },
        { 0x05, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC4, 0x00 },
        { 0x01, 0x00 },
        { 0x55, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC5, 0x00 },
        { 0x01, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC6, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC7, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC8, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xC9, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xCA, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xCB, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xCC, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xCD, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xCE, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x15 },
        { 0xCF, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD0, 0x00 },
        { 0x00, 0x01 },
        { 0x3F, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD1, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD2, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD3, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD4, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD5, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD6, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD7, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD8, 0x00 },
        { 0x00, 0x00 },
        { 0x48, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xD9, 0x00 },
        { 0x00, 0x00 },
        { 0x3C, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xDA, 0x03 },
        { 0x03, 0x03 },
        { 0x03, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xDB, 0x12 },
        { 0x12, 0x12 },
        { 0x12, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xDC, 0x03 },
        { 0x03, 0x03 },
        { 0x03, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xDD, 0x12 },
        { 0x12, 0x12 },
        { 0x12, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xDE, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xDF, 0x00 },
        { 0x00, 0x00 },
        { 0x02, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE0, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE1, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE2, 0x12 },
        { 0x13, 0x10 },
        { 0x10, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE3, 0x00 },
        { 0x29, 0x03 },
        { 0x33, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE4, 0x00 },
        { 0x1C, 0xFE },
        { 0xEF, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE5, 0x00 },
        { 0x1C, 0xFE },
        { 0xEF, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE6, 0x00 },
        { 0x1C, 0xFE },
        { 0xEF, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE7, 0x0F },
        { 0xE3, 0x01 },
        { 0x11, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE8, 0x0F },
        { 0xE3, 0x01 },
        { 0x11, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xE9, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xEA, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xEB, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xEC, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xED, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xEE, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xEF, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF0, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF1, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF2, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF3, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF4, 0x00 },
        { 0x80, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF5, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF6, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF7, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF8, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xF9, 0x00 },
        { 0x00, 0x00 },
        { 0x34, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xFA, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xFB, 0x00 },
        { 0x29, 0x03 },
        { 0x33, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xFC, 0x00 },
        { 0x29, 0x03 },
        { 0x33, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xFD, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xFE, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
    { CFG_META_BURST, 0x05 },
        { 0xFF, 0x00 },
        { 0x00, 0x00 },
        { 0x00, 0x00 },
};
